@@ -120,7 +120,7 @@ class Exceptions:
 
 class ComprehendClient:
     """
-    [Comprehend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client)
+    [Comprehend.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client)
     """
 
     exceptions: Exceptions
@@ -129,7 +129,7 @@ class ComprehendClient:
         self, TextList: List[str]
     ) -> BatchDetectDominantLanguageResponseTypeDef:
         """
-        [Client.batch_detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.batch_detect_dominant_language)
+        [Client.batch_detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.batch_detect_dominant_language)
         """
 
     def batch_detect_entities(
@@ -140,7 +140,7 @@ class ComprehendClient:
         ],
     ) -> BatchDetectEntitiesResponseTypeDef:
         """
-        [Client.batch_detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.batch_detect_entities)
+        [Client.batch_detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.batch_detect_entities)
         """
 
     def batch_detect_key_phrases(
@@ -151,7 +151,7 @@ class ComprehendClient:
         ],
     ) -> BatchDetectKeyPhrasesResponseTypeDef:
         """
-        [Client.batch_detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.batch_detect_key_phrases)
+        [Client.batch_detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.batch_detect_key_phrases)
         """
 
     def batch_detect_sentiment(
@@ -162,24 +162,24 @@ class ComprehendClient:
         ],
     ) -> BatchDetectSentimentResponseTypeDef:
         """
-        [Client.batch_detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.batch_detect_sentiment)
+        [Client.batch_detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.batch_detect_sentiment)
         """
 
     def batch_detect_syntax(
         self, TextList: List[str], LanguageCode: Literal["en", "es", "fr", "de", "it", "pt"]
     ) -> BatchDetectSyntaxResponseTypeDef:
         """
-        [Client.batch_detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.batch_detect_syntax)
+        [Client.batch_detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.batch_detect_syntax)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.can_paginate)
         """
 
     def classify_document(self, Text: str, EndpointArn: str) -> ClassifyDocumentResponseTypeDef:
         """
-        [Client.classify_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.classify_document)
+        [Client.classify_document documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.classify_document)
         """
 
     def create_document_classifier(
@@ -198,7 +198,7 @@ class ComprehendClient:
         Mode: Literal["MULTI_CLASS", "MULTI_LABEL"] = None,
     ) -> CreateDocumentClassifierResponseTypeDef:
         """
-        [Client.create_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.create_document_classifier)
+        [Client.create_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.create_document_classifier)
         """
 
     def create_endpoint(
@@ -210,7 +210,7 @@ class ComprehendClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateEndpointResponseTypeDef:
         """
-        [Client.create_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
+        [Client.create_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.create_endpoint)
         """
 
     def create_entity_recognizer(
@@ -227,88 +227,88 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> CreateEntityRecognizerResponseTypeDef:
         """
-        [Client.create_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.create_entity_recognizer)
+        [Client.create_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.create_entity_recognizer)
         """
 
     def delete_document_classifier(self, DocumentClassifierArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.delete_document_classifier)
+        [Client.delete_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.delete_document_classifier)
         """
 
     def delete_endpoint(self, EndpointArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.delete_endpoint)
+        [Client.delete_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.delete_endpoint)
         """
 
     def delete_entity_recognizer(self, EntityRecognizerArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.delete_entity_recognizer)
+        [Client.delete_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.delete_entity_recognizer)
         """
 
     def describe_document_classification_job(
         self, JobId: str
     ) -> DescribeDocumentClassificationJobResponseTypeDef:
         """
-        [Client.describe_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_document_classification_job)
+        [Client.describe_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_document_classification_job)
         """
 
     def describe_document_classifier(
         self, DocumentClassifierArn: str
     ) -> DescribeDocumentClassifierResponseTypeDef:
         """
-        [Client.describe_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_document_classifier)
+        [Client.describe_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_document_classifier)
         """
 
     def describe_dominant_language_detection_job(
         self, JobId: str
     ) -> DescribeDominantLanguageDetectionJobResponseTypeDef:
         """
-        [Client.describe_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_dominant_language_detection_job)
+        [Client.describe_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_dominant_language_detection_job)
         """
 
     def describe_endpoint(self, EndpointArn: str) -> DescribeEndpointResponseTypeDef:
         """
-        [Client.describe_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_endpoint)
+        [Client.describe_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_endpoint)
         """
 
     def describe_entities_detection_job(
         self, JobId: str
     ) -> DescribeEntitiesDetectionJobResponseTypeDef:
         """
-        [Client.describe_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_entities_detection_job)
+        [Client.describe_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_entities_detection_job)
         """
 
     def describe_entity_recognizer(
         self, EntityRecognizerArn: str
     ) -> DescribeEntityRecognizerResponseTypeDef:
         """
-        [Client.describe_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_entity_recognizer)
+        [Client.describe_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_entity_recognizer)
         """
 
     def describe_key_phrases_detection_job(
         self, JobId: str
     ) -> DescribeKeyPhrasesDetectionJobResponseTypeDef:
         """
-        [Client.describe_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_key_phrases_detection_job)
+        [Client.describe_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_key_phrases_detection_job)
         """
 
     def describe_sentiment_detection_job(
         self, JobId: str
     ) -> DescribeSentimentDetectionJobResponseTypeDef:
         """
-        [Client.describe_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_sentiment_detection_job)
+        [Client.describe_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_sentiment_detection_job)
         """
 
     def describe_topics_detection_job(
         self, JobId: str
     ) -> DescribeTopicsDetectionJobResponseTypeDef:
         """
-        [Client.describe_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.describe_topics_detection_job)
+        [Client.describe_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.describe_topics_detection_job)
         """
 
     def detect_dominant_language(self, Text: str) -> DetectDominantLanguageResponseTypeDef:
         """
-        [Client.detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.detect_dominant_language)
+        [Client.detect_dominant_language documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.detect_dominant_language)
         """
 
     def detect_entities(
@@ -316,10 +316,11 @@ class ComprehendClient:
         Text: str,
         LanguageCode: Literal[
             "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
+        ] = None,
+        EndpointArn: str = None,
     ) -> DetectEntitiesResponseTypeDef:
         """
-        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.detect_entities)
+        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.detect_entities)
         """
 
     def detect_key_phrases(
@@ -330,7 +331,7 @@ class ComprehendClient:
         ],
     ) -> DetectKeyPhrasesResponseTypeDef:
         """
-        [Client.detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.detect_key_phrases)
+        [Client.detect_key_phrases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.detect_key_phrases)
         """
 
     def detect_sentiment(
@@ -341,14 +342,14 @@ class ComprehendClient:
         ],
     ) -> DetectSentimentResponseTypeDef:
         """
-        [Client.detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.detect_sentiment)
+        [Client.detect_sentiment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.detect_sentiment)
         """
 
     def detect_syntax(
         self, Text: str, LanguageCode: Literal["en", "es", "fr", "de", "it", "pt"]
     ) -> DetectSyntaxResponseTypeDef:
         """
-        [Client.detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.detect_syntax)
+        [Client.detect_syntax documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.detect_syntax)
         """
 
     def generate_presigned_url(
@@ -359,7 +360,7 @@ class ComprehendClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.generate_presigned_url)
         """
 
     def list_document_classification_jobs(
@@ -369,7 +370,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListDocumentClassificationJobsResponseTypeDef:
         """
-        [Client.list_document_classification_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_document_classification_jobs)
+        [Client.list_document_classification_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_document_classification_jobs)
         """
 
     def list_document_classifiers(
@@ -379,7 +380,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListDocumentClassifiersResponseTypeDef:
         """
-        [Client.list_document_classifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_document_classifiers)
+        [Client.list_document_classifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_document_classifiers)
         """
 
     def list_dominant_language_detection_jobs(
@@ -389,14 +390,14 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListDominantLanguageDetectionJobsResponseTypeDef:
         """
-        [Client.list_dominant_language_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_dominant_language_detection_jobs)
+        [Client.list_dominant_language_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_dominant_language_detection_jobs)
         """
 
     def list_endpoints(
         self, Filter: EndpointFilterTypeDef = None, NextToken: str = None, MaxResults: int = None
     ) -> ListEndpointsResponseTypeDef:
         """
-        [Client.list_endpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_endpoints)
+        [Client.list_endpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_endpoints)
         """
 
     def list_entities_detection_jobs(
@@ -406,7 +407,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListEntitiesDetectionJobsResponseTypeDef:
         """
-        [Client.list_entities_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_entities_detection_jobs)
+        [Client.list_entities_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_entities_detection_jobs)
         """
 
     def list_entity_recognizers(
@@ -416,7 +417,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListEntityRecognizersResponseTypeDef:
         """
-        [Client.list_entity_recognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_entity_recognizers)
+        [Client.list_entity_recognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_entity_recognizers)
         """
 
     def list_key_phrases_detection_jobs(
@@ -426,7 +427,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListKeyPhrasesDetectionJobsResponseTypeDef:
         """
-        [Client.list_key_phrases_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_key_phrases_detection_jobs)
+        [Client.list_key_phrases_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_key_phrases_detection_jobs)
         """
 
     def list_sentiment_detection_jobs(
@@ -436,12 +437,12 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListSentimentDetectionJobsResponseTypeDef:
         """
-        [Client.list_sentiment_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_sentiment_detection_jobs)
+        [Client.list_sentiment_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_sentiment_detection_jobs)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_tags_for_resource)
         """
 
     def list_topics_detection_jobs(
@@ -451,7 +452,7 @@ class ComprehendClient:
         MaxResults: int = None,
     ) -> ListTopicsDetectionJobsResponseTypeDef:
         """
-        [Client.list_topics_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.list_topics_detection_jobs)
+        [Client.list_topics_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.list_topics_detection_jobs)
         """
 
     def start_document_classification_job(
@@ -466,7 +467,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartDocumentClassificationJobResponseTypeDef:
         """
-        [Client.start_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.start_document_classification_job)
+        [Client.start_document_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.start_document_classification_job)
         """
 
     def start_dominant_language_detection_job(
@@ -480,7 +481,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartDominantLanguageDetectionJobResponseTypeDef:
         """
-        [Client.start_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.start_dominant_language_detection_job)
+        [Client.start_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.start_dominant_language_detection_job)
         """
 
     def start_entities_detection_job(
@@ -498,7 +499,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartEntitiesDetectionJobResponseTypeDef:
         """
-        [Client.start_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.start_entities_detection_job)
+        [Client.start_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.start_entities_detection_job)
         """
 
     def start_key_phrases_detection_job(
@@ -515,7 +516,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartKeyPhrasesDetectionJobResponseTypeDef:
         """
-        [Client.start_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.start_key_phrases_detection_job)
+        [Client.start_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.start_key_phrases_detection_job)
         """
 
     def start_sentiment_detection_job(
@@ -532,7 +533,7 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartSentimentDetectionJobResponseTypeDef:
         """
-        [Client.start_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.start_sentiment_detection_job)
+        [Client.start_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.start_sentiment_detection_job)
         """
 
     def start_topics_detection_job(
@@ -547,56 +548,56 @@ class ComprehendClient:
         VpcConfig: "VpcConfigTypeDef" = None,
     ) -> StartTopicsDetectionJobResponseTypeDef:
         """
-        [Client.start_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.start_topics_detection_job)
+        [Client.start_topics_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.start_topics_detection_job)
         """
 
     def stop_dominant_language_detection_job(
         self, JobId: str
     ) -> StopDominantLanguageDetectionJobResponseTypeDef:
         """
-        [Client.stop_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.stop_dominant_language_detection_job)
+        [Client.stop_dominant_language_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.stop_dominant_language_detection_job)
         """
 
     def stop_entities_detection_job(self, JobId: str) -> StopEntitiesDetectionJobResponseTypeDef:
         """
-        [Client.stop_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.stop_entities_detection_job)
+        [Client.stop_entities_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.stop_entities_detection_job)
         """
 
     def stop_key_phrases_detection_job(
         self, JobId: str
     ) -> StopKeyPhrasesDetectionJobResponseTypeDef:
         """
-        [Client.stop_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.stop_key_phrases_detection_job)
+        [Client.stop_key_phrases_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.stop_key_phrases_detection_job)
         """
 
     def stop_sentiment_detection_job(self, JobId: str) -> StopSentimentDetectionJobResponseTypeDef:
         """
-        [Client.stop_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.stop_sentiment_detection_job)
+        [Client.stop_sentiment_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.stop_sentiment_detection_job)
         """
 
     def stop_training_document_classifier(self, DocumentClassifierArn: str) -> Dict[str, Any]:
         """
-        [Client.stop_training_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.stop_training_document_classifier)
+        [Client.stop_training_document_classifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.stop_training_document_classifier)
         """
 
     def stop_training_entity_recognizer(self, EntityRecognizerArn: str) -> Dict[str, Any]:
         """
-        [Client.stop_training_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.stop_training_entity_recognizer)
+        [Client.stop_training_entity_recognizer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.stop_training_entity_recognizer)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.untag_resource)
         """
 
     def update_endpoint(self, EndpointArn: str, DesiredInferenceUnits: int) -> Dict[str, Any]:
         """
-        [Client.update_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Client.update_endpoint)
+        [Client.update_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Client.update_endpoint)
         """
 
     @overload
@@ -604,7 +605,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_document_classification_jobs"]
     ) -> ListDocumentClassificationJobsPaginator:
         """
-        [Paginator.ListDocumentClassificationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
+        [Paginator.ListDocumentClassificationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs)
         """
 
     @overload
@@ -612,7 +613,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_document_classifiers"]
     ) -> ListDocumentClassifiersPaginator:
         """
-        [Paginator.ListDocumentClassifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
+        [Paginator.ListDocumentClassifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers)
         """
 
     @overload
@@ -620,7 +621,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_dominant_language_detection_jobs"]
     ) -> ListDominantLanguageDetectionJobsPaginator:
         """
-        [Paginator.ListDominantLanguageDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
+        [Paginator.ListDominantLanguageDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs)
         """
 
     @overload
@@ -628,7 +629,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_entities_detection_jobs"]
     ) -> ListEntitiesDetectionJobsPaginator:
         """
-        [Paginator.ListEntitiesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
+        [Paginator.ListEntitiesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs)
         """
 
     @overload
@@ -636,7 +637,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_entity_recognizers"]
     ) -> ListEntityRecognizersPaginator:
         """
-        [Paginator.ListEntityRecognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
+        [Paginator.ListEntityRecognizers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers)
         """
 
     @overload
@@ -644,7 +645,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_key_phrases_detection_jobs"]
     ) -> ListKeyPhrasesDetectionJobsPaginator:
         """
-        [Paginator.ListKeyPhrasesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
+        [Paginator.ListKeyPhrasesDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs)
         """
 
     @overload
@@ -652,7 +653,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_sentiment_detection_jobs"]
     ) -> ListSentimentDetectionJobsPaginator:
         """
-        [Paginator.ListSentimentDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
+        [Paginator.ListSentimentDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs)
         """
 
     @overload
@@ -660,7 +661,7 @@ class ComprehendClient:
         self, operation_name: Literal["list_topics_detection_jobs"]
     ) -> ListTopicsDetectionJobsPaginator:
         """
-        [Paginator.ListTopicsDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.19/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
+        [Paginator.ListTopicsDetectionJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.23/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
